
The Current Corpus Editor (CLD)
*******************************

CLD (which stands for "Computational Language Documentation") is the
current corpus editor. It is used to create, edit, and view corpora.

CLD runs either as a desktop application or as a web server.
This is accomplished by implementing the desktop application as a
private local web server that uses a web browser as user interface.

.. toctree::
   :maxdepth: 2

   userguide/index
   corpus/index
   imp/index
   pyext/index
